from skbuild import setup
setup(
    name="test_include_exclude_data",
    version="0.1.0",
    cmake_languages=(),
    packages=['hello', 'hello2'],
    include_package_data=True,
    exclude_package_data={'': [
        '*/*/*_data4_include_from_manifest_and_exclude_from_setup.txt',
        '*/*/*_data4_cmake_generated_and_exclude_from_setup.txt',
    ]}
)



from skbuild import setup

setup(
    name="hello",
    version="1.2.3",
    description="a minimal example package",
    author='The scikit-build team',
    license="MIT",
    packages=['hello'],
    test_suite='hello_tests'
)



# -*- coding: utf-8 -*-
"""
scikit-build is an improved build system generator for CPython C extensions.

This module provides the *glue* between the setuptools Python module and CMake.
"""

from ._version import get_versions
from .setuptools_wrap import setup  # noqa: F401

__author__ = 'The scikit-build team'
__email__ = 'scikit-build@googlegroups.com'
__version__ = '0.7.1'
__version__ = get_versions()['version']

__all__ = ["setup"]

del get_versions



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""test_hello_cpp
----------------------------------

Tries to build and test the `hello-cpp` sample project.
"""

import glob
import os
import pytest
import sysconfig
import tarfile

from skbuild.constants import CMAKE_BUILD_DIR, CMAKE_INSTALL_DIR, SKBUILD_DIR
from skbuild.utils import push_dir

from zipfile import ZipFile

from . import check_wheel_content, project_setup_py_test
from . import (_copy_dir, _tmpdir, SAMPLES_DIR)


def test_hello_builds():
    with push_dir():

        @project_setup_py_test("hello-cpp", ["build"])
        def run():
            pass

        # Check that a project can be build twice in a row
        # See issue scikit-build#120
        tmp_dir = run()[0]

        @project_setup_py_test("hello-cpp", ["build"], tmp_dir=tmp_dir)
        def another_run():
            pass

        another_run()


# @project_setup_py_test("hello-cpp", ["test"])
# def test_hello_works():
#     pass


@project_setup_py_test("hello-cpp", ["sdist"])
def test_hello_sdist():
    sdists_tar = glob.glob('dist/*.tar.gz')
    sdists_zip = glob.glob('dist/*.zip')
    assert sdists_tar or sdists_zip

    expected_content = [
        'hello-1.2.3/CMakeLists.txt',
        'hello-1.2.3/bonjour/__init__.py',
        'hello-1.2.3/bonjour/data/ciel.txt',
        'hello-1.2.3/bonjour/data/soleil.txt',
        'hello-1.2.3/bonjour/data/terre.txt',
        'hello-1.2.3/bonjourModule.py',
        'hello-1.2.3/hello/_hello.cxx',
        'hello-1.2.3/hello/CMakeLists.txt',
        'hello-1.2.3/hello/__init__.py',
        'hello-1.2.3/hello/__main__.py',
        'hello-1.2.3/setup.py',
        'hello-1.2.3/PKG-INFO'
    ]

    member_list = None
    if sdists_tar:
        expected_content.extend([
            'hello-1.2.3',
            'hello-1.2.3/bonjour',
            'hello-1.2.3/bonjour/data',
            'hello-1.2.3/hello'
        ])
        member_list = tarfile.open('dist/hello-1.2.3.tar.gz').getnames()

    elif sdists_zip:
        member_list = ZipFile('dist/hello-1.2.3.zip').namelist()

    assert expected_content and member_list
    assert sorted(expected_content) == sorted(member_list)


def test_hello_wheel():
    expected_content = [
        'hello/_hello%s' % (sysconfig.get_config_var('SO')),
        'hello/__init__.py',
        'hello/__main__.py',
        'hello/world.py',
        'helloModule.py',
        'bonjour/__init__.py',
        'bonjour/data/ciel.txt',
        'bonjour/data/soleil.txt',
        'bonjour/data/terre.txt',
        'bonjourModule.py'
    ]

    expected_distribution_name = 'hello-1.2.3'

    @project_setup_py_test("hello-cpp", ["bdist_wheel"])
    def build_wheel():
        whls = glob.glob('dist/*.whl')
        assert len(whls) == 1
        check_wheel_content(whls[0], expected_distribution_name, expected_content)
        os.remove(whls[0])
        assert not os.path.exists(whls[0])

        assert os.path.exists(os.path.join(CMAKE_BUILD_DIR, "CMakeCache.txt"))
        os.remove(os.path.join(CMAKE_BUILD_DIR, "CMakeCache.txt"))

    tmp_dir = build_wheel()[0]

    @project_setup_py_test("hello-cpp", ["--skip-cmake", "bdist_wheel"], tmp_dir=tmp_dir)
    def build_wheel_skip_cmake():
        assert not os.path.exists(os.path.join(CMAKE_BUILD_DIR, "CMakeCache.txt"))
        whls = glob.glob('dist/*.whl')
        assert len(whls) == 1
        check_wheel_content(whls[0], expected_distribution_name, expected_content)

    build_wheel_skip_cmake()


@pytest.mark.parametrize("dry_run", ['with-dry-run', 'without-dry-run'])
def test_hello_clean(dry_run, capfd):
    with push_dir():

        dry_run = dry_run == 'with-dry-run'

        @project_setup_py_test("hello-cpp", ["build"])
        def run_build():
            pass

        tmp_dir = run_build()[0]

        assert tmp_dir.join(SKBUILD_DIR).exists()

        # XXX Since using capfd.disabled() context manager prevents
        # the output from being captured atfer it exits, we display
        # a separator allowing to differentiate the build and clean output.
        print("<<-->>")

        clean_args = ["clean"]
        if dry_run:
            clean_args.append("--dry-run")

        @project_setup_py_test("hello-cpp", clean_args, tmp_dir=tmp_dir)
        def run_clean():
            pass

        run_clean()

        if not dry_run:
            assert not tmp_dir.join(SKBUILD_DIR).exists()
        else:
            assert tmp_dir.join(SKBUILD_DIR).exists()

        build_out, clean_out = capfd.readouterr()[0].split('<<-->>')
        assert 'Build files have been written to' in build_out
        assert 'Build files have been written to' not in clean_out


def test_hello_cleans(capfd):
    with push_dir():

        tmp_dir = _tmpdir("test_hello_cleans")

        _copy_dir(tmp_dir, os.path.join(SAMPLES_DIR, "hello-cpp"))

        @project_setup_py_test("hello-cpp", ["build"], tmp_dir=tmp_dir)
        def run_build():
            pass

        @project_setup_py_test("hello-cpp", ["clean"], tmp_dir=tmp_dir)
        def run_clean():
            pass

        # Check that a project can be cleaned twice in a row
        run_build()
        print("<<-->>")
        run_clean()
        print("<<-->>")
        run_clean()

    _, clean1_out, clean2_out = \
        capfd.readouterr()[0].split('<<-->>')

    clean1_out = clean1_out.strip()
    clean2_out = clean2_out.strip()

    assert "running clean" == clean1_out.splitlines()[0]
    assert "removing '{}'".format(CMAKE_INSTALL_DIR) == clean1_out.splitlines()[1]
    assert "removing '{}'".format(CMAKE_BUILD_DIR) == clean1_out.splitlines()[2]
    assert "removing '{}'".format(SKBUILD_DIR) == clean1_out.splitlines()[3]

    assert "running clean" == clean2_out


@project_setup_py_test("hello-cpp", ["develop"])
def test_hello_develop():
    for expected_file in [
        # These files are the "regular" source files
        'setup.py',
        'CMakeLists.txt',
        'bonjour/__init__.py',
        'bonjourModule.py',
        'hello/__init__.py',
        'hello/__main__.py',
        'hello/_hello.cxx',
        'hello/CMakeLists.txt',
        # These files are "generated" by CMake and
        # are copied from CMAKE_INSTALL_DIR
        'hello/_hello%s' % (sysconfig.get_config_var('SO')),
        'hello/world.py',
        'helloModule.py'
    ]:
        assert os.path.exists(expected_file)



from skbuild import setup

setup(
    name="hello",
    version="1.2.3",
    description=("a minimal example packagze that should always fail to build "
                 "because it provides a _hello.cxx with a compile error"),
    author='The scikit-build team',
    license="MIT",
    packages=['hello'],
)



"""This module defines custom ``generate_source_manifest`` setuptools
command."""

import os
import subprocess
import sys

from distutils.cmd import Command

from . import set_build_base_mixin
from ..constants import SKBUILD_DIR
from ..utils import new_style

SKBUILD_MARKER_FILE = os.path.join(SKBUILD_DIR, "_skbuild_MANIFEST")


class generate_source_manifest(set_build_base_mixin, new_style(Command)):
    """Custom setuptools command generating a `MANIFEST` file if
    not already provided."""

    description = "generate source MANIFEST"

    # pylint:disable=no-self-use
    def initialize_options(self):
        """Set default values for all the options that this command supports."""
        pass

    def run(self):
        """
        If neither a `MANIFEST`, nor a `MANIFEST.in` file is provided, and
        we are in a git repo, try to create a `MANIFEST` file from the output of
        `git ls-tree --name-only -r HEAD`.

        We need a reliable way to tell if an existing `MANIFEST` file is one
        we've generated.  distutils already uses a first-line comment to tell
        if the `MANIFEST` file was generated from `MANIFEST.in`, so we use a
        dummy file, `_skbuild_MANIFEST`, to avoid confusing distutils.
        """
        do_generate = (
            # If there's a MANIFEST.in file, we assume that we had nothing to do
            # with the project's manifest.
            not os.path.exists('MANIFEST.in')

            # otherwise, we check to see that there is no MANIFEST, ...
            and not os.path.exists('MANIFEST')  # ... or ...

            # ... (if there is one,) that we created it
            or os.path.exists(SKBUILD_MARKER_FILE)
        )

        if do_generate:

            try:
                with open('MANIFEST', 'wb') as manifest_file:
                    # Since Git < 2.11 does not support --recurse-submodules option, fallback to
                    # regular listing.
                    try:
                        manifest_file.write(
                            subprocess.check_output(['git', 'ls-files', '--recurse-submodules'])
                        )
                    except subprocess.CalledProcessError:
                        manifest_file.write(
                             subprocess.check_output(['git', 'ls-files'])
                         )
            except subprocess.CalledProcessError:
                sys.stderr.write(
                    '\n\n'
                    'Since scikit-build could not find MANIFEST.in or '
                    'MANIFEST, it tried to generate a MANIFEST file '
                    'automatically, but could not because it could not '
                    'determine which source files to include.\n\n'
                    'The command used was "git ls-files"\n'
                    '\n\n'
                )
                raise

            if not os.path.exists(SKBUILD_DIR):
                os.makedirs(SKBUILD_DIR)

            with open(SKBUILD_MARKER_FILE, 'w'):  # touch
                pass

    def finalize_options(self, *args, **kwargs):
        """Set final values for all the options that this command supports."""
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""test_skbuild
----------------------------------

Tests for `skbuild` module.
"""

import os
import platform
import pytest
import sys

from skbuild.constants import CMAKE_BUILD_DIR
from skbuild.exceptions import SKBuildError
from skbuild.platform_specifics import get_platform

from . import (get_cmakecache_variables, project_setup_py_test,
               push_dir, push_env, which)


def test_generator_selection():
    version = sys.version_info
    env_generator = os.environ.get("CMAKE_GENERATOR")
    this_platform = platform.system().lower()
    get_best_generator = get_platform().get_best_generator
    arch = platform.architecture()[0]

    if env_generator:
        assert(get_best_generator(env_generator).name == env_generator)

    if this_platform == "windows":
        # assert that we are running a supported version of python
        py_27_32 = (
            (version.major == 2 and version.minor >= 7) or
            (version.major == 3 and version.minor <= 2)
        )

        py_33_34 = (
            version.major == 3 and (
                3 <= version.minor <= 4
            )
        )

        py_35 = (
            version.major == 3 and
            version.minor >= 5
        )

        assert(len(tuple(filter(bool, (py_27_32, py_33_34, py_35)))) == 1)

        vs_ide_vcvars_path_pattern = \
            "C:/Program Files (x86)/" \
            "Microsoft Visual Studio %.1f/VC/vcvarsall.bat"

        # As of Dec 2016, this is available only for VS 9.0
        vs_for_python_vcvars_path_pattern = \
            "~/AppData/Local/Programs/Common/" \
            "Microsoft/Visual C++ for Python/%.1f/vcvarsall.bat"

        if py_27_32:
            vs_generator = "Visual Studio 9 2008"
            vs_version = 9
        elif py_33_34:
            vs_generator = "Visual Studio 10 2010"
            vs_version = 10
        else:
            vs_generator = "Visual Studio 14 2015"
            vs_version = 14

        vs_generator += (" Win64" if arch == "64bit" else "")

        vs_ide_vcvars_path = vs_ide_vcvars_path_pattern % vs_version
        vs_for_python_vcvars_path = os.path.expanduser(
            vs_for_python_vcvars_path_pattern % vs_version)

        generator = None

        # If environment exists, update the expected generator
        if (
                    os.path.exists(vs_for_python_vcvars_path) or
                    os.path.exists(vs_ide_vcvars_path)
        ) and which("ninja.exe"):
            generator = "Ninja"

        elif os.path.exists(vs_ide_vcvars_path):
            generator = vs_generator

        elif os.path.exists(vs_for_python_vcvars_path):
            generator = "NMake Makefiles"

        assert (get_best_generator().name == generator)

    elif this_platform in ["darwin", "linux"]:
        generator = "Unix Makefiles"
        if which("ninja"):
            generator = "Ninja"
        assert get_best_generator().name == generator


@pytest.mark.parametrize("generator, expected_make_program", [
    ("NMake Makefiles", "nmake"),
    ("Unix Makefiles", "make")
])
def test_generator(generator, expected_make_program):

    generator_platform = {
        "NMake Makefiles": ["windows"],
        "Unix Makefiles": ["darwin", "linux"]
    }
    assert generator in generator_platform

    this_platform = platform.system().lower()
    if this_platform not in generator_platform[generator]:
        pytest.skip("%s generator is available only on %s" % (
            generator, this_platform.title()))

    @project_setup_py_test("hello-cpp", ["build"])
    def run_build():
        pass

    with push_env(CMAKE_GENERATOR=generator):
        tmp_dir = run_build()[0]
        cmakecache = tmp_dir.join(CMAKE_BUILD_DIR).join("CMakeCache.txt")
        assert cmakecache.exists()
        variables = get_cmakecache_variables(str(cmakecache))
        make_program = (variables["CMAKE_MAKE_PROGRAM"][1]
                        if "CMAKE_MAKE_PROGRAM" in variables else "")
        assert make_program.endswith(expected_make_program) or \
            make_program.endswith("%s.exe" % expected_make_program)


@pytest.mark.parametrize(
    "generator_args",
    [
        ["-G", "invalid"],
        ["--", "-G", "invalid"],
    ]
)
def test_invalid_generator(generator_args):
    with push_dir():

        build_args = ["build"]
        build_args.extend(generator_args)

        @project_setup_py_test("hello-no-language", build_args, disable_languages_test=True)
        def run():
            pass

        failed = False
        message = ""
        try:
            run()
        except SystemExit as e:
            failed = isinstance(e.code, SKBuildError)
            message = str(e)

        assert failed
        assert "scikit-build could not get a working generator " \
               "for your system. Aborting build." in message



import glob
import os
import tarfile
import wheel

from pkg_resources import parse_version
from zipfile import ZipFile

from skbuild.utils import to_unix_path

from . import project_setup_py_test


def check_whls(project_name):
    whls = glob.glob('dist/*.whl')
    assert len(whls) == 1
    assert not whls[0].endswith('-none-any.whl')

    expected_content = [
        '%s.dist-info/top_level.txt' % project_name,
        '%s.dist-info/WHEEL' % project_name,
        '%s.dist-info/RECORD' % project_name,
        '%s.dist-info/METADATA' % project_name,
        'hello/__init__.py',
        'hello/cmake_generated_module.py',
        'hello/data/subdata/hello_data1_include_from_manifest.txt',
        'hello/data/subdata/hello_data2_include_from_manifest.txt',
        'hello/data/subdata/hello_data3_cmake_generated.txt',
        'hello/hello_data1_cmake_generated.txt',
        'hello/hello_data2_cmake_generated.txt',
        'hello/hello_include_from_manifest.txt',
        'hello2/__init__.py',
        'hello2/hello2_data1_cmake_generated.txt',
        'hello2/hello2_data2_cmake_generated.txt',
        'hello2/data2/subdata2/hello2_data3_cmake_generated.txt',
        'hello2/data2/subdata2/hello2_data1_include_from_manifest.txt',
        'hello2/data2/subdata2/hello2_data2_include_from_manifest.txt',
        'hello2/hello2_include_from_manifest.txt',
    ]
    if parse_version(wheel.__version__) < parse_version('0.31.0'):
        expected_content += [
            '%s.dist-info/DESCRIPTION.rst' % project_name,
            '%s.dist-info/metadata.json' % project_name
        ]

    archive = ZipFile(whls[0])
    member_list = archive.namelist()
    assert sorted(expected_content) == sorted(member_list)


def check_sdist(proj, base=''):
    sdists_tar = glob.glob('dist/*.tar.gz')
    sdists_zip = glob.glob('dist/*.zip')
    assert sdists_tar or sdists_zip

    expected_content = [
        to_unix_path(os.path.join(proj, 'setup.py')),
        to_unix_path(os.path.join(proj, base, 'hello/__init__.py')),
        to_unix_path(os.path.join(proj, base, 'hello/data/subdata/hello_data1_include_from_manifest.txt')),
        to_unix_path(os.path.join(proj, base, 'hello/data/subdata/hello_data2_include_from_manifest.txt')),
        to_unix_path(os.path.join(
            proj, base, 'hello/data/subdata/hello_data4_include_from_manifest_and_exclude_from_setup.txt')),
        to_unix_path(os.path.join(proj, base, 'hello/hello_include_from_manifest.txt')),
        to_unix_path(os.path.join(proj, base, 'hello2/__init__.py')),
        to_unix_path(os.path.join(proj, base, 'hello2/data2/subdata2/hello2_data1_include_from_manifest.txt')),
        to_unix_path(os.path.join(proj, base, 'hello2/data2/subdata2/hello2_data2_include_from_manifest.txt')),
        to_unix_path(os.path.join(
            proj, base, 'hello2/data2/subdata2/hello2_data4_include_from_manifest_and_exclude_from_setup.txt')),
        to_unix_path(os.path.join(proj, base, 'hello2/hello2_include_from_manifest.txt')),
        to_unix_path(os.path.join(proj, 'PKG-INFO'))
    ]

    member_list = None
    if sdists_tar:
        if base != '':
            expected_content.extend([to_unix_path(os.path.join(proj, base))])
        expected_content.extend([
            proj,
            to_unix_path(os.path.join(proj, base, 'hello')),
            to_unix_path(os.path.join(proj, base, 'hello/data')),
            to_unix_path(os.path.join(proj, base, 'hello/data/subdata')),
            to_unix_path(os.path.join(proj, base, 'hello2')),
            to_unix_path(os.path.join(proj, base, 'hello2/data2')),
            to_unix_path(os.path.join(proj, base, 'hello2/data2/subdata2'))
        ])
        member_list = tarfile.open('dist/%s.tar.gz' % proj).getnames()

    elif sdists_zip:
        member_list = ZipFile('dist/%s.zip' % proj).namelist()

    assert expected_content and member_list
    assert sorted(expected_content) == sorted(member_list)


@project_setup_py_test("test-include-exclude-data", ["bdist_wheel"])
def test_include_exclude_data():
    check_whls('test_include_exclude_data-0.1.0')


@project_setup_py_test("test-include-exclude-data", ["sdist"])
def test_hello_sdist():
    check_sdist('test_include_exclude_data-0.1.0')


@project_setup_py_test("test-include-exclude-data-with-base", ["bdist_wheel"])
def test_include_exclude_data_with_base():
    check_whls('test_include_exclude_data_with_base-0.1.0')


@project_setup_py_test("test-include-exclude-data-with-base", ["sdist"])
def test_hello_sdist_with_base():
    check_sdist('test_include_exclude_data_with_base-0.1.0', base='src')



from skbuild import setup

setup(
    name="manifest-in",
    version="1.2.3",
    description="a minimal example package with a MANIFEST.in",
    author='The scikit-build team',
    license="MIT",
    packages=['hello'],
)



import textwrap
import os
import pytest

import skbuild
from skbuild.constants import CMAKE_BUILD_DIR

from . import _tmpdir, execute_setup_py


def test_isolated_env_trigger_reconfigure(mocker):

    tmp_dir = _tmpdir('isolated_env_trigger_reconfigure')

    tmp_dir.join('setup.py').write(textwrap.dedent(
        """
        from skbuild import setup
        setup(
            name="test_isolated_env_trigger_reconfigure",
            version="1.2.3",
            description="A minimal example package",
            author="The scikit-build team",
            license="MIT",
        )
        """
    ))
    tmp_dir.join('CMakeLists.txt').write(textwrap.dedent(
        """
        message(FATAL_ERROR "This error message should not be displayed")
        """
    ))

    #
    # mock configure
    #
    def fake_configure(*args, **kwargs):
        # Simulate a successful configuration creating a CMakeCache.txt
        tmp_dir.ensure(CMAKE_BUILD_DIR, dir=1).join('CMakeCache.txt').write(textwrap.dedent(
            """
            //Name of generator.
            CMAKE_GENERATOR:INTERNAL=Ninja
            """
        ))

    # Skip real configuration creating the CMakeCache.txt expected by
    # "skbuild.setuptools_wrap._load_cmake_spec()" function
    mocker.patch('skbuild.cmaker.CMaker.configure', new=fake_configure)

    #
    # mock _save_cmake_spec
    #
    _save_cmake_spec_original = skbuild.setuptools_wrap._save_cmake_spec

    exit_after_saving_cmake_spec = "exit skbuild saving cmake spec"

    def _save_cmake_spec_mock(args):
        _save_cmake_spec_original(args)
        raise RuntimeError(exit_after_saving_cmake_spec)

    mocker.patch('skbuild.setuptools_wrap._save_cmake_spec', new=_save_cmake_spec_mock)

    #
    # mock make
    #
    exit_before_running_cmake = "exit skbuild running make"
    mocker.patch('skbuild.cmaker.CMaker.make', side_effect=RuntimeError(exit_before_running_cmake))

    # first build: "configure" and "_save_cmake_spec" are expected to be called
    with pytest.raises(RuntimeError, match=exit_after_saving_cmake_spec):
        with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
            pass

    # second build: no reconfiguration should happen, only "make" is expected to be called
    with pytest.raises(RuntimeError, match=exit_before_running_cmake):
        with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
            pass

    # since pip updates PYTHONPATH with the temporary path
    # where the project dependencies are installed, we simulate
    # this by updating the corresponding environment variable.
    os.environ["PYTHONPATH"] = "/path/to/anything"

    # after updating the env, reconfiguration is expected
    with pytest.raises(RuntimeError, match=exit_after_saving_cmake_spec):
        with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
            pass

    # no reconfiguration should happen
    with pytest.raises(RuntimeError, match=exit_before_running_cmake):
        with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
            pass

    # this is the other variable set by pip when doing isolated build
    os.environ["PYTHONNOUSERSITE"] = "1"

    # after updating the env, reconfiguration is expected
    with pytest.raises(RuntimeError, match=exit_after_saving_cmake_spec):
        with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
            pass

    # no reconfiguration should happen
    with pytest.raises(RuntimeError, match=exit_before_running_cmake):
        with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
            pass



"""This module defines custom implementation of ``sdist`` setuptools command."""

import os

from distutils import log as distutils_log
from distutils.command.sdist import sdist as _sdist

from . import set_build_base_mixin
from ..utils import distribution_hide_listing, new_style


class sdist(set_build_base_mixin, new_style(_sdist)):
    """Custom implementation of ``sdist`` setuptools command."""

    def make_release_tree(self, base_dir, files):
        """Handle --hide-listing option."""
        with distribution_hide_listing(self.distribution):
            super(sdist, self).make_release_tree(base_dir, files)
        distutils_log.info("%s %d files" % (
            "hard-linked" if hasattr(os, 'link') else "copied", len(files)))

    # pylint:disable=too-many-arguments, unused-argument
    def make_archive(self, base_name, _format, root_dir=None, base_dir=None,
                     owner=None, group=None):
        """Handle --hide-listing option."""
        distutils_log.info("creating '%s' %s archive and adding '%s' to it",
                           base_name, _format, base_dir)
        with distribution_hide_listing(self.distribution):
            super(sdist, self).make_archive(
                base_name, _format, root_dir, base_dir)

    def run(self, *args, **kwargs):
        """Force :class:`.egg_info.egg_info` command to run."""
        self.run_command('generate_source_manifest')
        super(sdist, self).run(*args, **kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""test_command_line
----------------------------------

Tests for various command line functionality.
"""

import os
import pytest

from skbuild.exceptions import SKBuildError
from skbuild.utils import push_dir, to_platform_path

from . import project_setup_py_test


@project_setup_py_test("hello-no-language", ["--help"], disable_languages_test=True)
def test_help(capsys):
    out, err = capsys.readouterr()
    assert "scikit-build options" not in out
    assert "Global options:" in out
    assert "usage:" in out


@project_setup_py_test("hello-no-language", ["--help-commands"], disable_languages_test=True)
def test_help_commands(capsys):
    out, err = capsys.readouterr()
    assert "scikit-build options" in out
    assert "--build-type" in out
    assert "Global options:" not in out
    assert "usage:" in out


@project_setup_py_test("hello-no-language", ["--author", "--name"], disable_languages_test=True)
def test_metadata_display(capsys):
    out, err = capsys.readouterr()
    assert "scikit-build options" not in out
    assert "Global options:" not in out
    assert "usage:" not in out
    assert "The scikit-build team" == out.splitlines()[0]
    assert "hello_no_language" == out.splitlines()[1]


def test_no_command():
    with push_dir():

        @project_setup_py_test("hello-no-language", [], disable_languages_test=True)
        def run():
            pass

        failed = False
        try:
            run()
        except SystemExit as e:
            failed = 'error: no commands supplied' in e.args[0]

        assert failed
        assert not os.path.exists('_skbuild')


def test_invalid_command():

    with push_dir():

        @project_setup_py_test("hello-no-language", ["unknown"], disable_languages_test=True)
        def run():
            pass

        failed = False
        try:
            run()
        except SystemExit as e:
            failed = 'error: invalid command' in e.args[0]

        assert failed
        assert not os.path.exists('_skbuild')


def test_too_many_separators():
    with push_dir():

        @project_setup_py_test("hello-no-language", ["--"] * 3, disable_languages_test=True)
        def run():
            pass

        failed = False
        try:
            run()
        except SystemExit as e:
            failed = e.args[0].startswith('ERROR: Too many')

        assert failed


@project_setup_py_test("hello-no-language",
                       ["build", "--", "-DMY_CMAKE_VARIABLE:BOOL=1"], disable_languages_test=True)
def test_cmake_args(capfd):
    out, err = capfd.readouterr()
    assert "Manually-specified variables were not used by the project" in err
    assert "MY_CMAKE_VARIABLE" in err


def test_cmake_executable_arg():

    cmake_executable = "/path/to/invalid/cmake"

    @project_setup_py_test("hello-no-language",
                           ["--cmake-executable", cmake_executable, "build"], disable_languages_test=True)
    def should_fail():
        pass

    failed = False
    message = ""
    try:
        should_fail()
    except SystemExit as e:
        failed = isinstance(e.code, SKBuildError)
        message = str(e)

    assert failed
    assert "Problem with the CMake installation, aborting build. CMake executable is %s" % cmake_executable in message


@pytest.mark.parametrize("action", ['sdist', 'bdist_wheel'])
@pytest.mark.parametrize("hide_listing", [True, False])
def test_hide_listing(action, hide_listing, capfd):

    cmd = [action]
    if hide_listing:
        cmd.insert(0, "--hide-listing")

    @project_setup_py_test("test-hide-listing", cmd, verbose_git=False, disable_languages_test=True)
    def run():
        pass

    run()

    out, _ = capfd.readouterr()
    if hide_listing:
        assert to_platform_path("bonjour/__init__.py") not in out
    else:
        assert to_platform_path("bonjour/__init__.py") in out

    if action == "sdist":
        what = "copied"
        if hasattr(os, 'link'):
            what = "hard-linked"
        assert "%s 10 files" % what in out
    elif action == "bdist_wheel":
        assert "copied 6 files" in out  # build_py
        assert "copied 9 files" in out  # install_lib
        assert "copied 0 files" in out  # install_scripts


@project_setup_py_test("hello-no-language", ["--force-cmake", "--help"], disable_languages_test=True)
def test_run_cmake_arg(capfd):
    out, _ = capfd.readouterr()
    assert "Generating done" in out


@project_setup_py_test("hello-no-language", ["--skip-cmake", "build"], disable_languages_test=True)
def test_skip_cmake_arg(capfd):
    out, _ = capfd.readouterr()
    assert "Generating done" not in out
